==> kmediafactory_0.5.1.orig.tar.gz: kmediafactory-0.5.1/plugins/video/videoplugin.h <==
//**************************************************************************
//   Copyright (C) 2004 by Petri Damstn
//   petri.damsten@iki.fi
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the
//   Free Software Foundation, Inc.,
//   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//**************************************************************************
#ifndef VIDEOPLUGIN_H
#define VIDEOPLUGIN_H

#include <kmf_stddef.h>
#include <kmediafactory/plugin.h>

class KAction;

class VideoPlugin :public KMF::Plugin
{
    Q_OBJECT
  public:
    VideoPlugin(QObject *parent, const char* name, const QStringList&);
    virtual ~VideoPlugin();

    virtual KMF::MediaObject* createMediaObject(const QDomElement& element);
    virtual const KMF::ConfigPage* configPage() const;

  public slots:
    virtual void init(const QString &type);
    virtual QStringList supportedProjectTypes();
    void slotAddVideo();

  private:
    KAction* addVideoAction;

    static void ffmpeg_av_log_callback(void *ptr, int level,
                                       const char *fmt, va_list vl);
};

#endif /* VIDEOPLUGIN_H */

==> kmediafactory_0.7.2.orig.tar.gz: kmediafactory-0.7.2/plugins/video/videoplugin.h <==
//**************************************************************************
//   Copyright (C) 2004-2006 by Petri Damsten
//   petri.damsten@iki.fi
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the
//   Free Software Foundation, Inc.,
//   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//**************************************************************************

#ifndef VIDEOPLUGIN_H
#define VIDEOPLUGIN_H

#include <kmf_stddef.h>
#include <kmediafactory/plugin.h>

class KAction;

class VideoPlugin : public KMF::Plugin
{
  Q_OBJECT
  public:
    VideoPlugin(QObject *parent, const QVariantList&);
    ~VideoPlugin();

  public slots:
    virtual void init(const QString &type);

  public:
    virtual KMF::MediaObject* createMediaObject(const QDomElement& element);
    virtual const KMF::ConfigPage* configPage() const;
    virtual QStringList supportedProjectTypes() const;

  public slots:
    void slotAddVideo();

  protected:
    QAction* setupActions();
};

#endif // VIDEOPLUGIN_H
